California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 045 - APPROVAL OF HEALTHCARE INSURANCE RATE CHANGES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343944 | CONSUMER WATCHDOG CAMPAIGN - YES ON 45, A COALITION OF CONSUMER ADVOCATES, NURSES, ATTORNEYS, AND POLICYHOLDERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343998 | NO ON 45-CALIFORNIANS AGAINST HIGHER HEALTHCARE COSTS, MAJOR FUNDING BY KAISER FNDN. HEALTH PLAN INC, WELLPOINT INC, BLUE SHIELD OF CA, WITH DOCTORS HOSPITALS HEALTH INSURERS & CALIFORNIA EMPLOYERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1367275 | NO ON 45: CALIFORNIA ASSOCIATION OF HEALTH UNDERWRITERS ISSUES COMMITTEE FOR RESPONSIBLE HEALTH INSURANCE REGULATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1336069 | CONSUMER WATCHDOG CAMPAIGN - YES ON 45 AND 46, A COALITION OF CONSUMER ADVOCATES, ATTORNEYS AND NURSES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1365283 | JONES - YES ON PROPOSITION 45; CALIFORNIANS FOR AFFORDABLE HEALTH INSURANCE: A BALLOT MEASURE COMMITTEE SUPPORTED BY CONSUMER ADVOCATES, WORKING FAMILIES, AND INSURANCE COMMISSIONER DAVE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
941597 | CALIFORNIA NURSES ASSOCIATION INITIATIVE POLITICAL ACTION COMMITTEE - YES ON PROP. 45 | SUPPORT